# -*- coding: utf-8 -*-

"""Top-level package for configure-django."""

__author__ = """Daniel Roy Greenfeld"""
__email__ = 'pydanny@gmail.com'
__version__ = '0.1.7'

from .configure_django import configure